@@ -4,13 +4,20 @@ warnings.filterwarnings("ignore", ".*g_object_unref.*", Warning)
 
 import logging
 import optparse
+import os
 
 import dbus
 import gobject
 import gio
 import pynotify
 
+try:
+    from xdg.BaseDirectory import xdg_config_home
+except ImportError:
+    xdg_config_home = os.path.expanduser('~/.config')
+
 import udiskie.device
+import udiskie.match
 
 class DeviceState:
     def __init__(self, mounted, has_media):
@@ -19,7 +26,9 @@ class DeviceState:
 
 
 class AutoMounter:
-    def __init__(self, bus=None):
+    CONFIG_PATH = 'udiskie/filters.conf'
+
+    def __init__(self, bus=None, filter_file=None):
         self.log = logging.getLogger('udiskie.mount.AutoMounter')
         self.last_device_state = {}
 
@@ -30,6 +39,11 @@ class AutoMounter:
         else:
             self.bus = bus
 
+        if not filter_file:
+            filter_file = os.path.join(xdg_config_home, self.CONFIG_PATH)
+        self.filters = udiskie.match.FilterMatcher((filter_file,))
+
+
         self.bus.add_signal_receiver(self.device_added,
                                      signal_name='DeviceAdded',
                                      bus_name='org.freedesktop.UDisks')
@@ -44,10 +58,14 @@ class AutoMounter:
         if device.is_handleable():
             try:
                 if not device.is_mounted():
-                    filesystem = str(device.id_type())
-                    options = []
+                    fstype = str(device.id_type())
+                    options = self.filters.get_mount_options(device)
+
+                    S = 'attempting to mount device %s (%s:%s)'
+                    self.log.info(S % (device, fstype, options))
+
                     try:
-                        device.mount(filesystem, options)
+                        device.mount(fstype, options)
                         self.log.info('mounted device %s' % (device,))
                     except dbus.exceptions.DBusException, dbus_err:
                         self.log.error('failed to mount device %s: %s' % (device,
@@ -119,6 +137,9 @@ def cli(args):
     parser.add_option('-v', '--verbose', action='store_true',
                       dest='verbose', default=False,
                       help='verbose output')
+    parser.add_option('-f', '--filters', action='store',
+                      dest='filters', default=None,
+                      metavar='FILE', help='filter FILE')
     (options, args) = parser.parse_args(args)
 
     log_level = logging.INFO
@@ -128,6 +149,6 @@ def cli(args):
 
     pynotify.init('udiskie.mount')
 
-    mounter = AutoMounter()
+    mounter = AutoMounter(bus=None, filter_file=options.filters)
     mounter.mount_present_devices()
     return gobject.MainLoop().run()
