@@ -1,8 +1,13 @@
+import warnings
+warnings.filterwarnings("ignore", ".*could not open display.*", Warning)
+warnings.filterwarnings("ignore", ".*g_object_unref.*", Warning)
+
 import logging
 import optparse
 import os
 
 import dbus
+import gio
 import pynotify
 
 import udiskie.device
@@ -22,9 +27,12 @@ def unmount_device(device):
                                                               dbus_err))
             return
 
-        pynotify.Notification('Device unmounted',
-                              '%s unmounted' % (device.device_file(),),
-                              'drive-removable-media').show()
+        try:
+            pynotify.Notification('Device unmounted',
+                                  '%s unmounted' % (device.device_file(),),
+                                  'drive-removable-media').show()
+        except gio.Error:
+            pass
     else:
         logger.debug('skipping unhandled device %s' % (device,))
 
@@ -45,7 +53,6 @@ def unmount(path):
 def unmount_all():
     """Unmount all filesystems handleable by udiskie."""
 
-    logger = logging.getLogger('udiskie.umount.unmount_all')
     bus = dbus.SystemBus()
     for device in udiskie.device.get_all(bus):
         unmount_device(device)
